# FPEFS: Feature Probability Estimation and Feature Selection

`fpefs` is a Python library that estimates the probability of features for selection based on unique values and target labels.

## Installation

You can install the package via pip:

```bash
pip install fpefs
```
